@@ -23,6 +23,14 @@ def http_configure(*names: str, ignore_missing: bool = False):
     Registry.default_registry().http_configure(*names, ignore_missing=ignore_missing)
 
 
+def save_http_configuration(name: str, data: Dict[str, Any]):
+    Registry.default_registry().save_http_configuration(name, data)
+
+
+def registry_configuration() -> Dict[str, Any]:
+    return Registry.default_registry().registry_configuration()
+
+
 def reconfigure():
     Registry.default_registry().reconfigure()
 
@@ -33,6 +41,10 @@ def get_configuration(object_name: str) -> Dict[str, Any]:
     return kwargs
 
 
+def get_kwarg(object_name: str, key: str) -> Any:
+    return Registry.default_registry().get_kwarg(object_name, key)
+
+
 def get(item: GetItemType, *args: Any, **kwargs: Any) -> Any:
     return Registry.default_registry().get(item, *args, **kwargs)
 
@@ -99,7 +111,9 @@ class Registry:
         if config_key not in self.configuration:
             raise RegistryError(f'Unable to read registry configuration, "{config_key}" not found in configuration')
 
-        return self.configuration[config_key]
+        _, kwargs = self.get_object_configuration(config_key)
+
+        return kwargs
 
     def configure(self, config: Union[str, ConfigurationType], file_type: Optional[str] = None, ignore_missing: bool = False, append: bool = True):
         if isinstance(config, dict):
@@ -123,6 +137,22 @@ class Registry:
             config_url = registry_config['configuration_url'] + '/' + name
             self.configure(config_url, ignore_missing=ignore_missing)
 
+    def save_http_configuration(self, name: str, data: Dict[str, Any]):
+        registry_config = self.registry_configuration()
+
+        if 'configuration_url' not in registry_config:
+            raise RegistryError(f'Cannot use `http_configure`, "$registry.configuration_url" not available in configuration')
+
+        config_url = registry_config['configuration_url'] + '/' + name
+
+        try:
+            response = requests.put(config_url, json=data)
+        except requests.ConnectionError:
+            raise RegistryError(f'Cannot save parameters to "{config_url}", error connecting to server')
+
+        if not response.ok:
+            raise RegistryError(f'Cannot save parameters to "{config_url}", response status: {response.status_code}')
+
     def reconfigure(self):
         self.configuration = {}
 
@@ -250,6 +280,14 @@ class Registry:
 
         return config_args, config_kwargs
 
+    def get_kwarg(self, object_name: str, key: str) -> Any:
+        config_args, config_kwargs = self.get_object_configuration(object_name)
+
+        if key not in config_kwargs:
+            raise KeyError(f'Cannot get configuration value for "{object_name}", "{key}" does not exist')
+
+        return config_kwargs[key]
+
     def get_object_factory(self, object_name: str) -> FactoryType:
         if object_name not in self.factories:
             if object_name not in self.configuration:
